@@ -1,6 +1,6 @@
 #!/bin/sh -e
-# check if debmake works as expected
-LC_ALL=en_US.UTF-8
+# debmake project-ver/ with different -u verx
+LC_ALL=C.UTF-8
 export LC_ALL
 
 # non-native without any origtar..\\ (auto -t option)
@@ -12,7 +12,7 @@ rm -rf ${PROJECT}
 mkdir ${PROJECT}
 echo "DUMMY ${PROJECT}" > ${PROJECT}/dummy-${PROJECT}
 cd ${PROJECT} || exit 1
-debmake -u "${VERSION}" -y 2>&1
+debmake -u "${VERSION}"
 cd .. || exit 1
 cd "${PROJECT}-${VERSION}" || exit 1
 test -x debian/rules
